@@ -14,8 +14,8 @@ our @EXPORT_OK = qw(
                        list_mentioned_dep_clauses
                );
 
-our $VERSION = '0.10'; # VERSION
-our $DATE = '2014-05-28'; # DATE
+our $VERSION = '0.11'; # VERSION
+our $DATE = '2015-09-03'; # DATE
 
 my $pa;
 
@@ -93,7 +93,7 @@ sub checkdep_prog {
     "";
 }
 
-sub _pa {
+sub riap_client {
     return $pa if $pa;
     require Perinci::Access;
     $pa = Perinci::Access->new;
@@ -102,7 +102,7 @@ sub _pa {
 
 sub checkdep_pkg {
     my ($cval) = @_;
-    my $res = _pa->request(info => $cval);
+    my $res = riap_client->request(info => $cval);
     $res->[0] == 200 or return "Can't perform 'info' Riap request on '$cval': ".
         "$res->[0] $res->[1]";
     $res->[2]{type} eq 'package' or return "$cval is not a Riap package";
@@ -111,7 +111,7 @@ sub checkdep_pkg {
 
 sub checkdep_func {
     my ($cval) = @_;
-    my $res = _pa->request(info => $cval);
+    my $res = riap_client->request(info => $cval);
     $res->[0] == 200 or return "Can't perform 'info' Riap request on '$cval': ".
         "$res->[0] $res->[1]";
     $res->[2]{type} eq 'function' or return "$cval is not a Riap function";
@@ -213,11 +213,11 @@ Perinci::Sub::DepChecker - Check dependencies from 'deps' property
 
 =head1 VERSION
 
-This document describes version 0.10 of Perinci::Sub::DepChecker (from Perl distribution Perinci-Sub-DepChecker), released on 2014-05-28.
+This document describes version 0.11 of Perinci::Sub::DepChecker (from Perl distribution Perinci-Sub-DepChecker), released on 2015-09-03.
 
 =head1 SYNOPSIS
 
- use Perinci::Spec::DepChecker qw(check_deps dep_must_be_satisfied);
+ use Perinci::Spec::DepChecker qw(check_deps dep_satisfy_rel list_mentioned_dep_clauses);
 
  my $err = check_deps($meta->{deps});
  print "Dependencies not met: $err" if $err;
@@ -232,7 +232,7 @@ module performs check on it.
 
 This module is currently mainly used by L<Perinci::Sub::Wrapper>.
 
-=for Pod::Coverage ^(checkdep_.*)$
+=for Pod::Coverage ^(checkdep_.*|riap_client)$
 
 =head1 FUNCTIONS
 
@@ -310,7 +310,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Su
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-DepChecker>.
+Source repository is at L<https://github.com/perlancar/perl-Perinci-Sub-DepChecker>.
 
 =head1 BUGS
 
@@ -322,11 +322,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
